Package: sesameData
Type: Package
Title: Supporting Data for SeSAMe Package
Description: Provides supporting annotation and test data for SeSAMe package. This includes chip tango addresses, mapping information, performance annotation, and trained predictor for Infinium array data. This package provides user access to essential annotation data for working with many generations of the Infinium DNA methylation array. Current we support human array (HM27, HM450, EPIC), mouse array (MM285) and the HorvathMethylChip40 (Mammal40) array.
Version: 1.28.0
Authors@R: c(person("Wanding", "Zhou", role = c("aut","cre"),
             email = "zhouwanding@gmail.com", comment = c(ORCID = "0000-0001-9126-1932")),
             person("Hui", "Shen", role = c("aut"),
             email = "Hui.Shen@vai.org"),
             person("Timothy", "Triche", role = "ctb"))
License: Artistic-2.0
Depends: R (>= 4.2.0), ExperimentHub, AnnotationHub
Imports: utils, readr, stringr, GenomicRanges (>= 1.61.1), S4Vectors,
        IRanges, Seqinfo
Suggests: BiocGenerics, GenomeInfoDb, sesame, testthat, knitr,
        rmarkdown
biocViews: ExperimentData, MicroarrayData, Genome, ExperimentHub,
        MethylationArrayData
URL: https://github.com/zwdzwd/sesame
BugReports: https://github.com/zwdzwd/sesame/issue
VignetteBuilder: knitr
NeedsCompilation: no
RoxygenNote: 7.3.2
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/sesameData
git_branch: RELEASE_3_22
git_last_commit: 851657b
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-11-04
Packaged: 2025-11-04 16:43:18 UTC; biocbuild
Author: Wanding Zhou [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9126-1932>),
  Hui Shen [aut],
  Timothy Triche [ctb]
Maintainer: Wanding Zhou <zhouwanding@gmail.com>
