# Generated by roxygen2: do not edit by hand

export(inferPlatformFromProbeIDs)
export(sesameDataCache)
export(sesameDataCacheAll)
export(sesameDataGet)
export(sesameDataGet_resetEnv)
export(sesameDataHas)
export(sesameDataList)
export(sesameData_annoProbes)
export(sesameData_check_genome)
export(sesameData_check_platform)
export(sesameData_getGenomeInfo)
export(sesameData_getManifestGRanges)
export(sesameData_getProbesByGene)
export(sesameData_getProbesByRegion)
export(sesameData_getTxnGRanges)
export(sesameData_txnToGeneGRanges)
import(AnnotationHub)
import(ExperimentHub)
import(GenomicRanges)
import(stringr)
import(utils)
importFrom(GenomicRanges,end)
importFrom(GenomicRanges,findOverlaps)
importFrom(GenomicRanges,mcols)
importFrom(GenomicRanges,start)
importFrom(GenomicRanges,trim)
importFrom(IRanges,IRanges)
importFrom(S4Vectors,queryHits)
importFrom(S4Vectors,subjectHits)
importFrom(Seqinfo,Seqinfo)
importFrom(readr,col_character)
importFrom(readr,col_integer)
importFrom(readr,cols)
importFrom(readr,read_tsv)
importFrom(stringr,str_replace)
importMethodsFrom(IRanges,subsetByOverlaps)
