% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genome.R
\name{build_GENCODE_gtf}
\alias{build_GENCODE_gtf}
\title{build GENCODE gtf}
\usage{
build_GENCODE_gtf(x)
}
\arguments{
\item{x}{GENCODE ftp url}
}
\value{
GRangesList
}
\description{
build GENCODE gtf
}
